/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        application_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	void Process_Io (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void Process_Io (void)
{
	static DWORD t = 0;
	//VendingMachine ();
	//Perform timer tasks (every second).
	if(TickGet() - t >= TICK_SECOND/2ul)
	{
		if (BUTTON2_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON2_IO == FALSE)
				Measure_Temperature ();
		}
		if (BUTTON3_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON3_IO == FALSE)
				Measure_Pot_Voltage ();
		}
	    t = TickGet();
	    LED0_IO ^= 1;
	}
}
//end ProcessIO


/******************************************************************************
 Function:        	void Measure_Pot_Voltage (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Pot_Voltage (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	char adc_result_lb;
	char adc_result_hb;
	char *buffer_pointer;
	
	for (index1 = 0; index1 <= 15; index1 ++)
		VOLTAGE [index1] = NULL;
	adc_result = Adc_Service (ADC_CHANNEL_5);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 *= (float)3300;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_result_hb = temp_reg3;
	adc_result_hb <<= 4;
	adc_result_hb |= temp_reg4;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_hb);
	VOLTAGE [0] = *(buffer_pointer + 0);
	VOLTAGE [1] = *(buffer_pointer + 1);
	adc_result_lb =  temp_reg5;
	adc_result_lb <<= 4;
	adc_result_lb |= temp_reg6;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_lb);
	VOLTAGE [2] = *(buffer_pointer + 0);
	VOLTAGE [3] = *(buffer_pointer + 1);
	VOLTAGE [4] = 0x6d;
	VOLTAGE [5] = 0x56;
	#if defined(USE_LCD)
		strcpypgm2ram((char*)LCDText, VOLTAGE);
		LCDUpdate();
	#endif
}
//end Measure_Pot_Voltage

/******************************************************************************
 Function:        	void Measure_Temperature (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Temperature (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	char adc_result_lb;
	char adc_result_hb;
	char *buffer_pointer;
	
	for (index1 = 0; index1 <= 15; index1 ++)
		TEMPERATURE [index1] = NULL;
	adc_result = Adc_Service (ADC_CHANNEL_4);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 = ((temp_reg1 * (float)3300) - (float)500) / (float)10;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_result_hb = temp_reg3;
	adc_result_hb <<= 4;
	adc_result_hb |= temp_reg4;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_hb);
	TEMPERATURE [0] = *(buffer_pointer + 0);
	TEMPERATURE [1] = *(buffer_pointer + 1);
	if (TEMPERATURE [0] == '0')
		TEMPERATURE [0] = 0x20;
	if (TEMPERATURE [1] == '0')
		TEMPERATURE [1] = 0x20;
	adc_result_lb =  temp_reg5;
	adc_result_lb <<= 4;
	adc_result_lb |= temp_reg6;
	buffer_pointer = Convert_Hex_to_Ascii (adc_result_lb);
	TEMPERATURE [2] = *(buffer_pointer + 0);
	TEMPERATURE [3] = *(buffer_pointer + 1);
	if (TEMPERATURE [2] == '0')
		TEMPERATURE [2] = 0x20;
	if (TEMPERATURE [3] == '0')
		TEMPERATURE [3] = 0x30;
	TEMPERATURE [4] = 0x64;
	TEMPERATURE [5] = 0x65;
	TEMPERATURE [6] = 0x67;
	TEMPERATURE [7] = 0x2d;
	TEMPERATURE [8] = 0x43;
	#if defined(USE_LCD)
		strcpypgm2ram((char*)LCDText, TEMPERATURE);
		LCDUpdate();
	#endif
}
//end Measure_Temperature


/******************************************************************************
 Function:        	void Initialize_Web_Form (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void Initialize_Web_Form (void)
{
	strcpypgm2ram((char*)machineDesc, (ROM char*)"Engineering Building A");
	machineDesc[32] = '\0';
	curItem = 0;
	curCredit = 0;
	
	// Display the boot message on the LCD
	strcpypgm2ram((char*)LCDText, "EnviroNet       ADC Test");
	LCDUpdate();
}
//end Initialize_Web_Form


/******************************************************************************
 Function:        	void VendingMachine (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void VendingMachine (void)
{
	static DWORD displayTimeout = (2 * TICK_SECOND);

	// Vending Machine State Machine
	switch(smVend)
	{
		case SM_IDLE:
			// Wait for a button press
			if(BUTTON0_IO == 0 || BUTTON1_IO == 0 || BUTTON2_IO == 0 || BUTTON3_IO == 0)
				smVend = SM_DEBOUNCE_DOWN;
			DelayMs(1);
			break;

		case SM_DEBOUNCE_DOWN:
			
			// Check if a button is down
			DelayMs(1);
			if(BUTTON3_IO == 0)
				smVend = SM_ADD_COIN;
			else if(BUTTON2_IO == 0)
				smVend = SM_TRY_VEND;
			else if(BUTTON1_IO == 0)
				smVend = SM_PREV;
			else if(BUTTON0_IO == 0)
				smVend = SM_NEXT;
			else
				smVend = SM_IDLE;
			break;
			
		case SM_ADD_COIN:
			// Add a quarter, up to $5.00
			if(curCredit < 20)
			{// Increase the credit
				curCredit++;
				smVend = SM_SHOW_MENU;
			}
			else
			{// Max credit was reached
				strcpypgm2ram((char*)LCDText, (ROM char*)" Coin Returned! Max credit is $5");
				LCDUpdate();
				displayTimeout = TickGet() + (4 * TICK_SECOND);
				smVend = SM_DISPLAY_WAIT;
			}
			break;
		
		case SM_TRY_VEND:
			// Try to vend a product
			if(Products[curItem].stock == 0)
			{// Product is sold out
				strcpypgm2ram((char*)LCDText, (ROM char*)"    SOLD OUT                    ");
			}
			else if(Products[curItem].price > curCredit)
			{
				strcpypgm2ram((char*)LCDText, (ROM char*)"Price:          Credit:         ");
				WritePriceLCD(Products[curItem].price, 8);
				WritePriceLCD(curCredit, 24);
			}
			else
			{
				strcpypgm2ram((char*)LCDText, (ROM char*)"   vending...                   ");
				curCredit -= Products[curItem].price;
				Products[curItem].stock--;
			}
			LCDUpdate();
			displayTimeout = TickGet() + (2 * TICK_SECOND);
			smVend = SM_DISPLAY_WAIT;
			break;
		
		case SM_PREV:
			// Move back one product in the list
			if(curItem > 0)
				curItem--;
			smVend = SM_SHOW_MENU;
			break;
		
		case SM_NEXT:
			// Move forward one product in the list
			if(curItem < MAX_PRODUCTS-1)
				curItem++;
			smVend = SM_SHOW_MENU;
			break;
		
		case SM_DISPLAY_WAIT:
			// Wait for the timout to occur before continuing
			//for(displayTimeout *= 1000; displayTimeout > 0; displayTimeout--)
				//DelayMs(1);
			if ((LONG) (TickGet()-displayTimeout) > (LONG)0)
			smVend = SM_SHOW_MENU;
			break;
			
		case SM_SHOW_MENU:				
			// Update the LCD with the menu
			WriteLCDMenu();
			smVend = SM_RELEASE_WAIT;
			break;
					
		case SM_RELEASE_WAIT:
			// Wait for all buttons to be released
			if(BUTTON0_IO == 1 && BUTTON1_IO == 1 && BUTTON2_IO == 1 && BUTTON3_IO == 1)
				smVend = SM_DEBOUNCE_UP;
			DelayMs(1);
			break;
		
		case SM_DEBOUNCE_UP:
			// Make sure all buttons were released
			DelayMs(1);
			if(BUTTON0_IO == 1 && BUTTON1_IO == 1 && BUTTON2_IO == 1 && BUTTON3_IO == 1)
				smVend = SM_IDLE;
			else
				smVend = SM_RELEASE_WAIT;
			break;
	}
}
//end VendingMachine


/******************************************************************************
 Function:        	void InitializeVend (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void InitializeVend (void)
{
	// Vending machine specific defaults
	strcpypgm2ram((char*)Products[0].name, (ROM char*)"Cola");
	strcpypgm2ram((char*)Products[1].name, (ROM char*)"Diet Cola");
	strcpypgm2ram((char*)Products[2].name, (ROM char*)"Root Beer");
	strcpypgm2ram((char*)Products[3].name, (ROM char*)"Orange");
	strcpypgm2ram((char*)Products[4].name, (ROM char*)"Lemonade");
	strcpypgm2ram((char*)Products[5].name, (ROM char*)"Iced Tea");
	strcpypgm2ram((char*)Products[6].name, (ROM char*)"Water");
	Products[0].price = 4;
	Products[1].price = 4;
	Products[2].price = 4;
	Products[3].price = 4;
	Products[4].price = 5;
	Products[5].price = 7;
	Products[6].price = 8;
	Products[0].stock = 15;
	Products[1].stock = 9;
	Products[2].stock = 22;
	Products[3].stock = 18;
	Products[4].stock = 4;
	Products[5].stock = 29;
	Products[6].stock = 14;

	strcpypgm2ram((char*)machineDesc, (ROM char*)"Building C4 - 2nd Floor NW");
	machineDesc[32] = '\0';
	curItem = 0;
	curCredit = 0;
	
	// Display the boot message on the LCD
	strcpypgm2ram((char*)LCDText, "Microchip       Vending Machine");
	LCDUpdate();
}
//end InitializeVend


/******************************************************************************
 Function:        	void WriteLCDMenu (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void WriteLCDMenu (void)
{// Update the LCD screen
	
	// Blank the LCD display
	LCDErase();
	
	// Show the name
	strcpy((char*)LCDText, (char*)Products[curItem].name);
	LCDText[strlen((char*)Products[curItem].name)] = ' ';
	
	// Show the price, or sold out status
	if(Products[curItem].stock == 0)
		memcpypgm2ram(&LCDText[12], (ROM void*)"SOLD", 4);
	else
		WritePriceLCD(Products[curItem].price, 11);
	
	// Show the current credit
	WritePriceLCD(curCredit, 16);
	
	// Show the vend button if available
	if(Products[curItem].stock != 0 && Products[curItem].price <= curCredit)
		memcpypgm2ram(&LCDText[22], (ROM void*)"Vend", 4);
	else
		memcpypgm2ram(&LCDText[23], (ROM void*)"--", 2);
	
	// Show the rest of the buttons
	if(curItem != 0)
		memcpypgm2ram(&LCDText[27], (ROM void*)"<<", 2);
	if(curItem != MAX_PRODUCTS-1)
		memcpypgm2ram(&LCDText[30], (ROM void*)">>", 2);

	// Update to the screen	
	LCDUpdate();
}
//end WriteLCDMenu


/******************************************************************************
 Function:        	void WritePriceLCD (BYTE price, BYTE position)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void WritePriceLCD (BYTE price, BYTE position)
{
	LCDText[position++] = '$';
	
	// Write the dollars
	LCDText[position++] = (price >> 2) + '0';
	
	LCDText[position++] = '.';
	
	// Write the cents
	switch(price & 0x03)
	{
		case 0:
			LCDText[position++] = '0';
			LCDText[position]   = '0';
			break;
		case 1:
			LCDText[position++] = '2';
			LCDText[position]   = '5';
			break;
		case 2:
			LCDText[position++] = '5';
			LCDText[position]   = '0';
			break;
		case 3:
			LCDText[position++] = '7';
			LCDText[position]   = '5';
			break;
	}
}
//end WritePriceLCD

//========== end application_service.c ==========
