/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        application_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	void Process_Io (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void Process_Io (void)
{
	static DWORD t;	// = 0;
	//VendingMachine ();
	//Perform timer tasks (every second).
	if(TickGet() - t >= TICK_SECOND/2ul)
	{
		TIMER_COUNTER_1 += 1;
		if (TIMER_COUNTER_1 >= 9)
		{
			TIMER_COUNTER_1 = NULL;
			TIMER_FLAG_1 = TRUE;
		}
		Measure_Acceleration ();
		if (BUTTON2_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON2_IO == FALSE)
				Measure_Temperature ();
		}
		if (BUTTON3_IO == FALSE)
		{
			DelayMs(10);
			if (BUTTON3_IO == FALSE)
				Measure_Pot_Voltage ();
		}
	    t = TickGet();
	    LED0_IO ^= 1;
	    memset (TCP_DATA_STRING, (int)"\0", 100);
	    strcpy (TCP_DATA_STRING, X_AXIS_DATA_STRING);
	    strcat (TCP_DATA_STRING, ",");
	    strcat (TCP_DATA_STRING, Y_AXIS_DATA_STRING);
	    strcat (TCP_DATA_STRING, ",");
	    strcat (TCP_DATA_STRING, Z_AXIS_DATA_STRING);
	}
}
//end ProcessIO


/******************************************************************************
 Function:        	void Measure_Pot_Voltage (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Pot_Voltage (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	int adc_hexidecimal_result;
	char *ascii_buffer_pointer;
	char measurement_string [] = "Voltage: ";
	char units_string [] = "mV";
	
	adc_result = Adc_Service (ADC_CHANNEL_5);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 *= (float)3300;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_hexidecimal_result = temp_reg3;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg4;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg5;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg6;
	ascii_buffer_pointer = Convert_Hex_to_Ascii ((long)adc_hexidecimal_result, WORD_NIBBLE_EXTENT);
	for (index1 = 0; index1 <= (WORD_NIBBLE_EXTENT - 1); index1 ++)
		VOLTAGE [index1] = *(ascii_buffer_pointer + ((WORD_NIBBLE_EXTENT - 1) - index1));
	Trim_Leading_Zeros (VOLTAGE);
	#if defined(USE_LCD)
		LCDErase ();
		memset (LCD_DISPLAY_STRING, (int)"\0", 17);
		strcpy (LCD_DISPLAY_STRING, measurement_string);
		strcat (LCD_DISPLAY_STRING, VOLTAGE);
		strcat (LCD_DISPLAY_STRING, units_string);
		strcpypgm2ram((char*)LCDText, LCD_DISPLAY_STRING);
		LCDUpdate();
	#endif
}
//end Measure_Pot_Voltage


/******************************************************************************
 Function:        	void Measure_Temperature (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Temperature (void)
 {
 	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	int adc_result;
	int adc_hexidecimal_result;
	char *ascii_buffer_pointer;
	char measurement_string [] = "Temp: ";
	char units_string [] = "deg-C";
	
	adc_result = Adc_Service (ADC_CHANNEL_4);
	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 = ((temp_reg1 * (float)3300) - (float)500) / (float)10;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	adc_hexidecimal_result = temp_reg3;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg4;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg5;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg6;
	ascii_buffer_pointer = Convert_Hex_to_Ascii ((long)adc_hexidecimal_result, WORD_NIBBLE_EXTENT);
	for (index1 = 0; index1 <= (WORD_NIBBLE_EXTENT - 1); index1 ++)
		TEMPERATURE [index1] = *(ascii_buffer_pointer + ((WORD_NIBBLE_EXTENT - 1) - index1));
	Trim_Leading_Zeros (TEMPERATURE);
	#if defined(USE_LCD)
		LCDErase ();
		memset (LCD_DISPLAY_STRING, (int)"\0", 17);
		strcpy (LCD_DISPLAY_STRING, measurement_string);
		strcat (LCD_DISPLAY_STRING, TEMPERATURE);
		strcat (LCD_DISPLAY_STRING, units_string);
		strcpypgm2ram((char*)LCDText, LCD_DISPLAY_STRING);
		LCDUpdate();
	#endif
}
//end Measure_Temperature


/******************************************************************************
 Function:        	void Measure_Acceleration (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Measure_Acceleration (void)
 {
	int adc_result;
	char x_axis_string [] = "x:";
	char y_axis_string [] = "y:";
	char z_axis_string [] = "z:";
	char units_string [] = "g";
	
	adc_result = Adc_Service (ADC_CHANNEL_3);
	Convert_To_Acceleration (adc_result, X_AXIS_DATA_STRING);
	adc_result = Adc_Service (ADC_CHANNEL_8);
	Convert_To_Acceleration (adc_result, Y_AXIS_DATA_STRING);
	adc_result = Adc_Service (ADC_CHANNEL_9);
	Convert_To_Acceleration (adc_result, Z_AXIS_DATA_STRING);
	#if defined(USE_LCD)
		LCDErase ();
		memset (LCD_DISPLAY_STRING, (int)"\0", 33);
		strcpy (LCD_DISPLAY_STRING, x_axis_string);
		strcat (LCD_DISPLAY_STRING, X_AXIS_DATA_STRING);
		strcat (LCD_DISPLAY_STRING, units_string);
		strcat (LCD_DISPLAY_STRING, ", ");
		strcat (LCD_DISPLAY_STRING, y_axis_string);
		strcat (LCD_DISPLAY_STRING, Y_AXIS_DATA_STRING);
		strcat (LCD_DISPLAY_STRING, units_string);
		strcat (LCD_DISPLAY_STRING, z_axis_string);
		strcat (LCD_DISPLAY_STRING, Z_AXIS_DATA_STRING);
		strcat (LCD_DISPLAY_STRING, units_string);
		strcpypgm2ram((char*)LCDText, LCD_DISPLAY_STRING);
		LCDUpdate();
	#endif
}
//end Measure_Temperature


/******************************************************************************
 Function:        	void Convert_To_Acceleration (int adc_result, char *axis)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
 void Convert_To_Acceleration (int adc_result, char *axis)
 {
	unsigned char index1;
	float temp_reg1;
	int temp_reg2;
	char temp_reg3;
	char temp_reg4;
	char temp_reg5;
	char temp_reg6;
	char sign_flag;
	int adc_hexidecimal_result;
	char *ascii_buffer_pointer;
	char temp_buffer [AXIS_DATA_STRING_SIZE] = " ";

	temp_reg1 = (float)adc_result / (float)1024;
	temp_reg1 *= (float)3289;
	if (temp_reg1 >= (float)1650)
	{
		sign_flag = TRUE;
		temp_reg1 -= (float)1645;
	}
	else
	{
		sign_flag = FALSE;
		temp_reg1 = (float)1650 - temp_reg1;
	}
	temp_reg1 /= (float) 0.068;	//(float)0.054;
	temp_reg2 = (int)temp_reg1;
	temp_reg3 =  temp_reg2 / 1000;	//thousands
	temp_reg4 = (temp_reg2 - (temp_reg3 * 1000)) / 100;	//hundreds
	temp_reg5 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) / 10;	//tens
	temp_reg6 = ((temp_reg2 - (temp_reg3 * 1000)) - (temp_reg4 * 100)) - (temp_reg5 * 10);	//ones
	
	adc_hexidecimal_result = temp_reg3;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg4;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg5;
	adc_hexidecimal_result <<= 4;
	adc_hexidecimal_result |= temp_reg6;
	ascii_buffer_pointer = Convert_Hex_to_Ascii ((long)adc_hexidecimal_result, WORD_NIBBLE_EXTENT);
	for (index1 = 0; index1 <= (WORD_NIBBLE_EXTENT - 1); index1 ++)
		*(axis + index1) = *(ascii_buffer_pointer + ((WORD_NIBBLE_EXTENT - 1) - index1));
	
	if (sign_flag == TRUE)
		temp_buffer [0] = 0x2b;
	else
		temp_buffer [0] = 0x2d;
	temp_buffer [1] = *(axis + 0);
	temp_buffer [2] = 0x2e;
	temp_buffer [3] = *(axis + 1);
	memcpy (axis, temp_buffer, AXIS_DATA_STRING_SIZE);
}
//end Convert_To_Acceleration

//========== end application_service.c ==========
