/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        ascii_hex_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC24
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:

*/


//Includes
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	unsigned char Convert_Ascii_to_Hex (unsigned char *buffer_pointer)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Convert ASCII characters to HEX byte
 *****************************************************************************/
unsigned char Convert_Ascii_to_Hex (unsigned char *buffer_pointer)
{
	unsigned char index1;
	//BOOL communication_error = FALSE;
	unsigned char hex_byte = NULL;
	unsigned char nibble_extent = BYTE_NIBBLE_EXTENT;
	//unsigned char nibble_offset = 4;
	unsigned char hex_nibble [nibble_extent];
	
	for (index1 = 0; index1 <= (nibble_extent - 1); index1 ++)
	{
		hex_nibble [index1] = *(buffer_pointer + index1);
		//convert all received ASCII alpha characters to upper case
		if ((hex_nibble [index1] >= 'a') && (hex_nibble [index1] <= 'z'))
			hex_nibble [index1] = (char)toupper((int)hex_nibble [index1]);
		//check that a hex nibble is possibly being sent (i.e 0x0 (= 0x30 for '0') to 0xF (= 0x46 for 'F')
		if (((hex_nibble [index1] >= 'A') && (hex_nibble [index1] <= 'F')) || ((hex_nibble [index1] >= '0') && (hex_nibble [index1] <= '9')))
		{
			//convert nibble
			if ((hex_nibble [index1] >= 'A') && (hex_nibble [index1] <= 'F'))
				hex_nibble [index1] = hex_nibble [index1] - 0x37;
			else
				hex_nibble [index1] = hex_nibble [index1] - 0x30;
		}
		//if not a hex nibble attempting conversion, then set error and break
		else
		{
			//communication_error = TRUE;
			break;
		}
	}
/*
	if (communication_error == FALSE)
	{
		hex_byte = hex_nibble [0];
		hex_byte <<= nibble_offset;
		hex_byte |= hex_nibble [1];
	}
	else
		hex_byte = COMMUNICATION_ERROR;
*/
	return hex_byte;
}	
//end Convert_Ascii_To_Hex


/******************************************************************************
 Function:        	char *Convert_Hex_to_Ascii (long hex_buffer, char size)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Convert HEX characters to ASCII byte
 *****************************************************************************/
char *Convert_Hex_to_Ascii (long hex_buffer, char nibble_size)
{
	char ascii_buffer_pointer [LONG_NIBBLE_EXTENT];
	static char hex_nibble [LONG_NIBBLE_EXTENT];
	unsigned char index1;
	
	for (index1 = 0; index1 <= (LONG_NIBBLE_EXTENT - 1); index1 ++)
	{
		ascii_buffer_pointer [index1] = NULL;
		hex_nibble [index1] = NULL;
	}
	//load hex_nibble array from low nibble to high nibble
	for (index1 = 0; index1 <= (nibble_size - 1); index1 ++)
		hex_nibble [index1] = (char)((hex_buffer >> (4 * index1)) & 0x0000000F);
	
	for (index1 = 0; index1 <= (nibble_size - 1); index1 ++)
	{
		//convert nibbles to ASCII representations
		if ((hex_nibble [index1] >= 0x00) && ( hex_nibble [index1] <= 0x09))
			ascii_buffer_pointer [index1] = hex_nibble [index1] + 0x30;
		else
			ascii_buffer_pointer [index1] = hex_nibble [index1] + 0x37;
	}
	return ascii_buffer_pointer;
}
//end Convert_Hex_to_Ascii


/******************************************************************************
 Function:        	void Trim_Leading_Zeros (char *buffer_pointer)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Remove leading zeros and justify
 *****************************************************************************/
void Trim_Leading_Zeros (char *buffer_pointer)
{
	unsigned char index1;
	char leading_zeros;
	char temp_buffer1 [5];
	
	leading_zeros = NULL;
	memcpy (temp_buffer1, buffer_pointer, 5);	
	for (index1 = 0; index1 <= (WORD_NIBBLE_EXTENT - 1); index1 ++)
	{
		if (temp_buffer1 [index1] == '0')
			leading_zeros = index1 + 1;
		else
			break;
	}
	if (leading_zeros <= 3)
	{
		for (index1 = 0; index1 <= ((WORD_NIBBLE_EXTENT - 1) - leading_zeros); index1 ++)
			temp_buffer1 [index1] = temp_buffer1 [index1 + leading_zeros];
	}
	else
	{
		index1 = 0;
		temp_buffer1 [index1] = '0';
		index1 ++;
	}
	while (index1 <= 3)
	{
		temp_buffer1 [index1] = 0x00;
		index1 ++;
	}
	memcpy (buffer_pointer, temp_buffer1, 5);
}
//end Trim_Leading_Zeros

//========== end ascii_hex_service.c ==========
