/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        initialization_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
#include "TCPIP Stack/TCPIP.h"

#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
	#include "TCPIP Stack/ZeroconfLinkLocal.h"
#endif
#if defined(STACK_USE_ZEROCONF_MDNS_SD)
	#include "TCPIP Stack/ZeroconfMulticastDNS.h"
#endif
#include "include files.h"


//Fuses


//Variables


//Private Prototypes


//Declarations


/******************************************************************************
 Function:        	void Initialization_Service (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       This routine initializes the hardware.  It is a generic initialization
    				routine for many of the Microchip development boards, using definitions
    				in HardwareProfile.h to determine specific initialization.
 *****************************************************************************/
void Initialization_Service (void)
{
	// Initialize application specific hardware
	Initialize_System();

	#if defined(USE_LCD)
		// Initialize and display the stack version on the LCD
		LCDInit();
		DelayMs(100);
		strcpypgm2ram((char*)LCDText, "TCPStack " TCPIP_STACK_VERSION "  "
			"                ");
		LCDUpdate();
	#endif	//#if defined(USE_LCD)

	// Initialize stack-related hardware components that may be 
	// required by the UART configuration routines
    TickInit();
    TIMER_COUNTER_1 = NULL;
    TIMER_FLAG_1 = FALSE;
	#if defined(STACK_USE_MPFS2)
		MPFSInit();
	#endif	//#if defined(STACK_USE_MPFS2)

	// Initialize Stack and application related NV variables into AppConfig.
	Initialize_Application_Configuration ();
	//InitializeVend();
	Initialize_Web_Form ();

    // Initiates board setup process if button is depressed 
	// on startup
    if(BUTTON0_IO == 0u)
    {
		#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
			// Invalidate the EEPROM contents if BUTTON0 is held down for more than 4 seconds
			DWORD StartTime = TickGet();
			LED_PUT(0x00);
					
			while(BUTTON0_IO == 0u)
			{
				if(TickGet() - StartTime > 4*TICK_SECOND)
				{
					#if defined(EEPROM_CS_TRIS)
					    XEEBeginWrite(0x0000);
					    XEEWrite(0xFF);
					    XEEWrite(0xFF);
					    XEEEndWrite();
				    #elif defined(SPIFLASH_CS_TRIS)
					    SPIFlashBeginWrite(0x0000);
					    SPIFlashWrite(0xFF);
					    SPIFlashWrite(0xFF);
				    #endif
				    
					#if defined(STACK_USE_UART)
						putrsUART("\r\n\r\nBUTTON0 held for more than 4 seconds.  Default settings restored.\r\n\r\n");
					#endif
	
					LED_PUT(0x0F);
					while((LONG)(TickGet() - StartTime) <= (LONG)(9*TICK_SECOND/2));
					LED_PUT(0x00);
					while(BUTTON0_IO == 0u);
					Reset();
					break;
				}
			}
		#endif	//#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)

		#if defined(STACK_USE_UART)
        	DoUARTConfig();
		#endif	//#if defined(STACK_USE_UART)
    }

	// Initialize core stack layers (MAC, ARP, TCP, UDP) and
	// application modules (HTTP, SNMP, etc.)
    StackInit();

    #if defined(WF_CS_TRIS)
    	WF_Connect();
    #endif	//#if defined(WF_CS_TRIS)

	// Initialize any application-specific modules or functions/
	// For this demo application, this only includes the
	// UART 2 TCP Bridge
	#if defined(STACK_USE_UART2TCP_BRIDGE)
		UART2TCPBridgeInit();
	#endif	//#if defined(STACK_USE_UART2TCP_BRIDGE)

	#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
    	ZeroconfLLInitialize();
	#endif	//#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)

	#if defined(STACK_USE_ZEROCONF_MDNS_SD)
		mDNSInitialize(MY_DEFAULT_HOST_NAME);
		mDNSServiceRegister(
			(const char *) "DemoWebServer",	// base name of the service
			"_http._tcp.local",			    // type of the service
			80,				                // TCP or UDP port, at which this service is available
			((const BYTE *)"path=/index.htm"),	// TXT info
			//((const BYTE *)"path=/Default.aspx"),	// TXT info
			1,								    // auto rename the service when if needed
			NULL,							    // no callback function
			NULL							    // no application context
			);
	
	    mDNSMulticastFilterRegister();			
	#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)
}
//end Initialization_Service


/******************************************************************************
 Function:        	void Initialize_Web_Form (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
void Initialize_Web_Form (void)
{
	strcpypgm2ram((char*)machineDesc, (ROM char*)"Engineering Building A");
	machineDesc[32] = '\0';
	curItem = 0;
	curCredit = 0;
	
	// Display the boot message on the LCD
	strcpypgm2ram((char*)LCDText, "EnviroNet       ADC Test");
	LCDUpdate();
}
//end Initialize_Web_Form


/******************************************************************************
 Function:        	void Initialize_System(void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       This routine initializes the hardware.  It is a generic initialization
    				routine for many of the Microchip development boards, using definitions
    				in HardwareProfile.h to determine specific initialization.
 *****************************************************************************/
void Initialize_System(void)
{	
	// LEDs
	LED0_TRIS = 0;
	LED1_TRIS = 0;
	LED2_TRIS = 0;
	LED3_TRIS = 0;
	LED4_TRIS = 0;
	LED5_TRIS = 0;
	LED6_TRIS = 0;
	LED7_TRIS = 0;
	LED_PUT(0x00);

	#if defined(__18CXX)
		// Enable 4x/5x/96MHz PLL on PIC18F87J10, PIC18F97J60, PIC18F87J50, etc.
	    OSCTUNE = 0x40;
	
		// Set up analog features of PORTA
		#if defined(__18F87J11) || defined(_18F87J11) || defined(__18F87J50) || defined(_18F87J50)
			ADCON0 = 0x01;		// ADON, Channel 0, Vdd/Vss is +/-REF
			WDTCONbits.ADSHR = 1;
			ANCON0 = 0xFC;		// AN0 (POT) and AN1 (temp sensor) are anlog
			ANCON1 = 0xFF;
			WDTCONbits.ADSHR = 0;		
		#else
			ADCON0 = 0x01;		// ADON, Channel 0
			ADCON1 = 0x0E;		// Vdd/Vss is +/-REF, AN0 is analog
		#endif	//#if defined(__18F87J11) || defined(_18F87J11) || defined(__18F87J50) || defined(_18F87J50)
		
		ADCON2 = 0xBE;		// Right justify, 20TAD ACQ time, Fosc/64 (~21.0kHz)
	   	// Enable internal PORTB pull-ups
	    INTCON2bits.RBPU = 0;
		// Configure USART
	    TXSTA = 0x20;
	    RCSTA = 0x90;
	
		// See if we can use the high baud rate setting
		#if ((GetPeripheralClock()+2*BAUD_RATE)/BAUD_RATE/4 - 1) <= 255
			SPBRG = (GetPeripheralClock()+2*BAUD_RATE)/BAUD_RATE/4 - 1;
			TXSTAbits.BRGH = 1;
		#else	// Use the low baud rate setting
			SPBRG = (GetPeripheralClock()+8*BAUD_RATE)/BAUD_RATE/16 - 1;
		#endif	//#if ((GetPeripheralClock()+2*BAUD_RATE)/BAUD_RATE/4 - 1) <= 255
	
		// Enable Interrupts
		RCONbits.IPEN = 1;		// Enable interrupt priorities
	    INTCONbits.GIEH = 1;
	    INTCONbits.GIEL = 1;
	
	    // Do a calibration A/D conversion
		#if defined(__18F87J10) || defined(__18F86J15) || defined(__18F86J10) || defined(__18F85J15) || defined(__18F85J10) || defined(__18F67J10) || defined(__18F66J15) || defined(__18F66J10) || defined(__18F65J15) || defined(__18F65J10) || defined(__18F97J60) || defined(__18F96J65) || defined(__18F96J60) || defined(__18F87J60) || defined(__18F86J65) || defined(__18F86J60) || defined(__18F67J60) || defined(__18F66J65) || defined(__18F66J60) || \
		     defined(_18F87J10) ||  defined(_18F86J15) || defined(_18F86J10)  ||  defined(_18F85J15) ||  defined(_18F85J10) ||  defined(_18F67J10) ||  defined(_18F66J15) ||  defined(_18F66J10) ||  defined(_18F65J15) ||  defined(_18F65J10) ||  defined(_18F97J60) ||  defined(_18F96J65) ||  defined(_18F96J60) ||  defined(_18F87J60) ||  defined(_18F86J65) ||  defined(_18F86J60) ||  defined(_18F67J60) ||  defined(_18F66J65) ||  defined(_18F66J60)
			ADCON0bits.ADCAL = 1;
		    ADCON0bits.GO = 1;
			while(ADCON0bits.GO);
			ADCON0bits.ADCAL = 0;
		#elif defined(__18F87J11) || defined(__18F86J16) || defined(__18F86J11) || defined(__18F67J11) || defined(__18F66J16) || defined(__18F66J11) || \
			   defined(_18F87J11) ||  defined(_18F86J16) ||  defined(_18F86J11) ||  defined(_18F67J11) ||  defined(_18F66J16) ||  defined(_18F66J11) || \
			  defined(__18F87J50) || defined(__18F86J55) || defined(__18F86J50) || defined(__18F67J50) || defined(__18F66J55) || defined(__18F66J50) || \
			   defined(_18F87J50) ||  defined(_18F86J55) ||  defined(_18F86J50) ||  defined(_18F67J50) ||  defined(_18F66J55) ||  defined(_18F66J50)
			ADCON1bits.ADCAL = 1;
		    ADCON0bits.GO = 1;
			while(ADCON0bits.GO);
			ADCON1bits.ADCAL = 0;
		#endif	//#if defined(__18F87J10) || defined(__18F86J15) || defined(__18F86J10) || defined(__18F85J15) || defined(__18F85J10) || defined(__18F67J10) || defined(__18F66J15) || defined(__18F66J10) || defined(__18F65J15) || defined(__18F65J10) || defined(__18F97J60) || defined(__18F96J65) || defined(__18F96J60) || defined(__18F87J60) || defined(__18F86J65) || defined(__18F86J60) || defined(__18F67J60) || defined(__18F66J65) || defined(__18F66J60) || \
		     	//defined(_18F87J10) ||  defined(_18F86J15) || defined(_18F86J10)  ||  defined(_18F85J15) ||  defined(_18F85J10) ||  defined(_18F67J10) ||  defined(_18F66J15) ||  defined(_18F66J10) ||  defined(_18F65J15) ||  defined(_18F65J10) ||  defined(_18F97J60) ||  defined(_18F96J65) ||  defined(_18F96J60) ||  defined(_18F87J60) ||  defined(_18F86J65) ||  defined(_18F86J60) ||  defined(_18F67J60) ||  defined(_18F66J65) ||  defined(_18F66J60)
	
	#else	// 16-bit C30 and and 32-bit C32
		#if defined(__PIC32MX__)
		{
			// Enable multi-vectored interrupts
			INTEnableSystemMultiVectoredInt();
			
			// Enable optimal performance
			SYSTEMConfigPerformance(GetSystemClock());
			mOSCSetPBDIV(OSC_PB_DIV_1);				// Use 1:1 CPU Core:Peripheral clocks
			
			// Disable JTAG port so we get our I/O pins back, but first
			// wait 50ms so if you want to reprogram the part with 
			// JTAG, you'll still have a tiny window before JTAG goes away.
			// The PIC32 Starter Kit debuggers use JTAG and therefore must not 
			// disable JTAG.
			DelayMs(50);
			#if !defined(__MPLAB_DEBUGGER_PIC32MXSK) && !defined(__MPLAB_DEBUGGER_FS2)
				DDPCONbits.JTAGEN = 0;
			#endif
			LED_PUT(0x00);				// Turn the LEDs off
			
			CNPUESET = 0x00098000;		// Turn on weak pull ups on CN15, CN16, CN19 (RD5, RD7, RD13), which is connected to buttons on PIC32 Starter Kit boards
		}
		#endif	//#if defined(__PIC32MX__)
	
		#if defined(__dsPIC33F__) || defined(__PIC24H__)
			// Crank up the core frequency
			PLLFBD = 38;				// Multiply by 40 for 160MHz VCO output (8MHz XT oscillator)
			CLKDIV = 0x0000;			// FRC: divide by 2, PLLPOST: divide by 2, PLLPRE: divide by 2
		
			// Port I/O
			AD1PCFGHbits.PCFG23 = 1;	// Make RA7 (BUTTON1) a digital input
			AD1PCFGHbits.PCFG20 = 1;	// Make RA12 (INT1) a digital input for MRF24WB0M PICtail Plus interrupt
	
			// ADC
		    AD1CHS0 = 0;				// Input to AN0 (potentiometer)
			AD1PCFGLbits.PCFG5 = 0;		// Disable digital input on AN5 (potentiometer)
			AD1PCFGLbits.PCFG4 = 0;		// Disable digital input on AN4 (TC1047A temp sensor)
	
	
		#elif defined(__dsPIC33E__)||defined(__PIC24E__)
	
			// Crank up the core frequency
			PLLFBD = 38;				/* M  = 30	*/
			CLKDIVbits.PLLPOST = 0;		/* N1 = 2	*/
			CLKDIVbits.PLLPRE = 0;		/* N2 = 2	*/
			OSCTUN = 0;	
			
		    /*	Initiate Clock Switch to Primary
		     *	Oscillator with PLL (NOSC= 0x3)*/
		    __builtin_write_OSCCONH(0x03);		
			__builtin_write_OSCCONL(0x01);
			// Disable Watch Dog Timer
		    RCONbits.SWDTEN = 0;
			while (OSCCONbits.COSC != 0x3); 
			while (_LOCK == 0);			/* Wait for PLL lock at 60 MIPS */		
			// Port I/O
			ANSELAbits.ANSA7 = 0 ;   //Make RA7 (BUTTON1) a digital input
			#if defined ENC100_INTERFACE_MODE > 0
				ANSELEbits.ANSE0 = 0;      // Make these PMP pins as digital output when the interface is parallel.
				ANSELEbits.ANSE1 = 0;
				ANSELEbits.ANSE2 = 0;
				ANSELEbits.ANSE3 = 0;	
				ANSELEbits.ANSE4 = 0;
				ANSELEbits.ANSE5 = 0;
				ANSELEbits.ANSE6 = 0;
				ANSELEbits.ANSE7 = 0;	
				ANSELBbits.ANSB10 = 0;
				ANSELBbits.ANSB11 = 0;
				ANSELBbits.ANSB12 = 0;
				ANSELBbits.ANSB13 = 0;
				ANSELBbits.ANSB15 = 0;
			#endif	//#if defined ENC100_INTERFACE_MODE > 0
	
			ANSELEbits.ANSE8= 0 ;    // Make RE8(INT1) a digital input for ZeroG ZG2100M PICtail 
						
			AD1CHS0 = 0;		     // Input to AN0 (potentiometer)
			ANSELBbits.ANSB0= 1;     // Input to AN0 (potentiometer)
			ANSELBbits.ANSB5= 1;     // Disable digital input on AN5 (potentiometer)
			ANSELBbits.ANSB4= 1;     // Disable digital input on AN4 (TC1047A temp sensor)
						
			ANSELDbits.ANSD7 =0;     //  Digital Pin Selection for S3(Pin 83) and S4(pin 84).
			ANSELDbits.ANSD6 =0;
				
			ANSELGbits.ANSG6 =0;     // Enable Digital input for RG6 (SCK2)
			ANSELGbits.ANSG7 =0;     // Enable Digital input for RG7 (SDI2)
			ANSELGbits.ANSG8 =0;     // Enable Digital input for RG8 (SDO2)
			ANSELGbits.ANSG9 =0;     // Enable Digital input for RG9 (CS)
			
			// SPI Interface, UART can be used for debugging. Not allowed for other interfaces.
			#if defined ENC100_INTERFACE_MODE == 0	
				RPOR9 = 0x0300;          //RP101= U2TX
				RPINR19 = 0X0064;  		 //RP100= U2RX
			#endif	//	#if defined ENC100_INTERFACE_MODE == 0
	
			#if defined WF_CS_TRIS
				RPINR1bits.INT3R = 30;
				WF_CS_IO = 1;
				WF_CS_TRIS = 0;		
			#endif	//#if defined WF_CS_TRIS
	
		#else
			#if defined(__PIC24F__)
				CLKDIVbits.RCDIV = 0;		// Set 1:1 8MHz FRC postscalar
			#endif	//#if defined(__PIC24F__)
			
			// ADC
		    #if defined(__PIC24FJ256DA210__) || defined(__PIC24FJ256GB210__)
		    	// Disable analog on all pins
		    	ANSA = 0x0000;
		    	ANSB = 0x0000;
		    	ANSC = 0x0000;
		    	ANSD = 0x0000;
		    	ANSE = 0x0000;
		    	ANSF = 0x0000;
		    	ANSG = 0x0000;
			#else
			    AD1CHS = 0;					// Input to AN0 (potentiometer)
				AD1PCFGbits.PCFG4 = 0;		// Disable digital input on AN4 (TC1047A temp sensor)
				// PIC32MX460F512L and PIC32MX795F512L PIMs has different pinout to accomodate USB module
				#if defined(__32MX460F512L__) || defined(__32MX795F512L__)	
					AD1PCFGbits.PCFG2 = 0;		// Disable digital input on AN2 (potentiometer)
				#else
					AD1PCFGbits.PCFG5 = 0;		// Disable digital input on AN5 (potentiometer)
				#endif	//#if defined(__32MX460F512L__) || defined(__32MX795F512L__)
			#endif	//#if defined(__PIC24FJ256DA210__) || defined(__PIC24FJ256GB210__)
		#endif	//#if defined(__dsPIC33F__) || defined(__PIC24H__)
	
		// ADC
		AD1CON1 = 0x84E4;			// Turn on, auto sample start, auto-convert, 12 bit mode (on parts with a 12bit A/D)
		AD1CON2 = 0x0404;			// AVdd, AVss, int every 2 conversions, MUXA only, scan
		AD1CON3 = 0x1003;			// 16 Tad auto-sample, Tad = 3*Tcy
		// PIC32MX460F512L and PIC32MX795F512L PIMs has different pinout to accomodate USB module
		#if defined(__32MX460F512L__) || defined(__32MX795F512L__)	
			AD1CSSL = 1<<2;				// Scan pot
		#else
			AD1CSSL = 1<<5;				// Scan pot
		#endif	//#if defined(__32MX460F512L__) || defined(__32MX795F512L__)
	
		// UART
		#if defined(STACK_USE_UART)
			#if defined(__PIC24E__) || defined(__dsPIC33E__)
				// UART to be used in case of ENC28J60 or MRF24WB0M
				#if defined (ENC_CS_IO) || defined (WF_CS_IO)   
					__builtin_write_OSCCONL(OSCCON & 0xbf);
					RPOR9bits.RP101R = 3; //Map U2TX to RF5
					RPINR19bits.U2RXR = 0;
					RPINR19bits.U2RXR = 0x64; //Map U2RX to RF4
					__builtin_write_OSCCONL(OSCCON | 0x40);
				#endif	//#if defined (ENC_CS_IO) || defined (WF_CS_IO)
				
				// UART to be used only in case of SPI interface with ENC624Jxxx
				#if(ENC100_INTERFACE_MODE == 0)                 
						__builtin_write_OSCCONL(OSCCON & 0xbf);
					RPOR9bits.RP101R = 3; //Map U2TX to RF5
					RPINR19bits.U2RXR = 0;
					RPINR19bits.U2RXR = 0x64; //Map U2RX to RF4
					__builtin_write_OSCCONL(OSCCON | 0x40);
				#endif	//#if(ENC100_INTERFACE_MODE == 0)
			#endif	//#if defined(__PIC24E__) || defined(__dsPIC33E__)
	
			UARTTX_TRIS = 0;
			UARTRX_TRIS = 1;
			UMODE = 0x8000;			// Set UARTEN.  Note: this must be done before setting UTXEN
	
			#if defined(__C30__)
				USTA = 0x0400;		// UTXEN set
				#define CLOSEST_UBRG_VALUE ((GetPeripheralClock()+8ul*BAUD_RATE)/16/BAUD_RATE-1)
				#define BAUD_ACTUAL (GetPeripheralClock()/16/(CLOSEST_UBRG_VALUE+1))
			#else
				USTA = 0x00001400;		// RXEN set, TXEN set
				#define CLOSEST_UBRG_VALUE ((GetPeripheralClock()+8ul*BAUD_RATE)/16/BAUD_RATE-1)
				#define BAUD_ACTUAL (GetPeripheralClock()/16/(CLOSEST_UBRG_VALUE+1))
			#endif	//#if defined(__C30__)
		
			#define BAUD_ERROR ((BAUD_ACTUAL > BAUD_RATE) ? BAUD_ACTUAL-BAUD_RATE : BAUD_RATE-BAUD_ACTUAL)
			#define BAUD_ERROR_PRECENT	((BAUD_ERROR*100+BAUD_RATE/2)/BAUD_RATE)
			
			#if (BAUD_ERROR_PRECENT > 3)
				#warning UART frequency error is worse than 3%
			#elif (BAUD_ERROR_PRECENT > 2)
				#warning UART frequency error is worse than 2%
			#endif	//#if (BAUD_ERROR_PRECENT > 3)
		
			UBRG = CLOSEST_UBRG_VALUE;
		#endif	//#if defined(STACK_USE_UART)
	#endif	//#if defined(__18CXX)

	// Deassert all chip select lines so there isn't any problem with 
	// initialization order.  Ex: When ENC28J60 is on SPI2 with Explorer 16, 
	// MAX3232 ROUT2 pin will drive RF12/U2CTS ENC28J60 CS line asserted, 
	// preventing proper 25LC256 EEPROM operation.
	#if defined(ENC_CS_TRIS)
		ENC_CS_IO = 1;
		ENC_CS_TRIS = 0;
	#endif	//#if defined(ENC_CS_TRIS)
	
	#if defined(ENC100_CS_TRIS)
		ENC100_CS_IO = (ENC100_INTERFACE_MODE == 0);
		ENC100_CS_TRIS = 0;
	#endif	//#if defined(ENC100_CS_TRIS)
	
	#if defined(EEPROM_CS_TRIS)
		EEPROM_CS_IO = 1;
		EEPROM_CS_TRIS = 0;
	#endif	//#if defined(EEPROM_CS_TRIS)
	
	#if defined(SPIRAM_CS_TRIS)
		SPIRAM_CS_IO = 1;
		SPIRAM_CS_TRIS = 0;
	#endif	//#if defined(SPIRAM_CS_TRIS)
	
	#if defined(SPIFLASH_CS_TRIS)
		SPIFLASH_CS_IO = 1;
		SPIFLASH_CS_TRIS = 0;
	#endif	//#if defined(SPIFLASH_CS_TRIS)
	
	#if defined(WF_CS_TRIS)
		WF_CS_IO = 1;
		WF_CS_TRIS = 0;
	#endif	//#if defined(WF_CS_TRIS)
	
	#if defined(PIC24FJ64GA004_PIM)
		__builtin_write_OSCCONL(OSCCON & 0xBF);  // Unlock PPS
	
		// Remove some LED outputs to regain other functions
		LED1_TRIS = 1;		// Multiplexed with BUTTON0
		LED5_TRIS = 1;		// Multiplexed with EEPROM CS
		LED7_TRIS = 1;		// Multiplexed with BUTTON1
		
		// Inputs
		RPINR19bits.U2RXR = 19;			//U2RX = RP19
		RPINR22bits.SDI2R = 20;			//SDI2 = RP20
		RPINR20bits.SDI1R = 17;			//SDI1 = RP17
		
		// Outputs
		RPOR12bits.RP25R = U2TX_IO;		//RP25 = U2TX  
		RPOR12bits.RP24R = SCK2OUT_IO; 	//RP24 = SCK2
		RPOR10bits.RP21R = SDO2_IO;		//RP21 = SDO2
		RPOR7bits.RP15R = SCK1OUT_IO; 	//RP15 = SCK1
		RPOR8bits.RP16R = SDO1_IO;		//RP16 = SDO1
		
		AD1PCFG = 0xFFFF;				//All digital inputs - POT and Temp are on same pin as SDO1/SDI1, which is needed for ENC28J60 commnications
	
		__builtin_write_OSCCONL(OSCCON | 0x40); // Lock PPS
	#endif	//#if defined(PIC24FJ64GA004_PIM)
	
	#if defined(__PIC24FJ256DA210__)
		__builtin_write_OSCCONL(OSCCON & 0xBF);  // Unlock PPS
	
		// Inputs
		RPINR19bits.U2RXR = 11;	// U2RX = RP11
		RPINR20bits.SDI1R = 0;	// SDI1 = RP0
		RPINR0bits.INT1R = 34;	// Assign RE9/RPI34 to INT1 (input) for MRF24WB0M Wi-Fi PICtail Plus interrupt
		
		// Outputs
		RPOR8bits.RP16R = 5;	// RP16 = U2TX
		RPOR1bits.RP2R = 8; 	// RP2 = SCK1
		RPOR0bits.RP1R = 7;		// RP1 = SDO1
	
		__builtin_write_OSCCONL(OSCCON | 0x40); // Lock PPS
	#endif	//#if defined(__PIC24FJ256DA210__)
	
	#if defined(__PIC24FJ256GB110__) || defined(__PIC24FJ256GB210__)
		__builtin_write_OSCCONL(OSCCON & 0xBF);  // Unlock PPS
		
		// Configure SPI1 PPS pins (ENC28J60/ENCX24J600/MRF24WB0M or other PICtail Plus cards)
		RPOR0bits.RP0R = 8;		// Assign RP0 to SCK1 (output)
		RPOR7bits.RP15R = 7;	// Assign RP15 to SDO1 (output)
		RPINR20bits.SDI1R = 23;	// Assign RP23 to SDI1 (input)
	
		// Configure SPI2 PPS pins (25LC256 EEPROM on Explorer 16)
		RPOR10bits.RP21R = 11;	// Assign RG6/RP21 to SCK2 (output)
		RPOR9bits.RP19R = 10;	// Assign RG8/RP19 to SDO2 (output)
		RPINR22bits.SDI2R = 26;	// Assign RG7/RP26 to SDI2 (input)
		
		// Configure UART2 PPS pins (MAX3232 on Explorer 16)
		#if !defined(ENC100_INTERFACE_MODE) || (ENC100_INTERFACE_MODE == 0) || defined(ENC100_PSP_USE_INDIRECT_RAM_ADDRESSING)
		RPINR19bits.U2RXR = 10;	// Assign RF4/RP10 to U2RX (input)
		RPOR8bits.RP17R = 5;	// Assign RF5/RP17 to U2TX (output)
		#endif	//#if !defined(ENC100_INTERFACE_MODE) || (ENC100_INTERFACE_MODE == 0) || defined(ENC100_PSP_USE_INDIRECT_RAM_ADDRESSING)
		
		// Configure INT1 PPS pin (MRF24WB0M Wi-Fi PICtail Plus interrupt signal when in SPI slot 1)
		RPINR0bits.INT1R = 33;	// Assign RE8/RPI33 to INT1 (input)
	
		// Configure INT3 PPS pin (MRF24WB0M Wi-Fi PICtail Plus interrupt signal when in SPI slot 2)
		RPINR1bits.INT3R = 40;	// Assign RC3/RPI40 to INT3 (input)
	
		__builtin_write_OSCCONL(OSCCON | 0x40); // Lock PPS
	#endif	//#if defined(__PIC24FJ256GB110__) || defined(__PIC24FJ256GB210__)
	
	#if defined(__PIC24FJ256GA110__)
		__builtin_write_OSCCONL(OSCCON & 0xBF);  // Unlock PPS
		
		// Configure SPI2 PPS pins (25LC256 EEPROM on Explorer 16 and ENC28J60/ENCX24J600/MRF24WB0M or other PICtail Plus cards)
		// Note that the ENC28J60/ENCX24J600/MRF24WB0M PICtails SPI PICtails must be inserted into the middle SPI2 socket, not the topmost SPI1 slot as normal.  This is because PIC24FJ256GA110 A3 silicon has an input-only RPI PPS pin in the ordinary SCK1 location.  Silicon rev A5 has this fixed, but for simplicity all demos will assume we are using SPI2.
		RPOR10bits.RP21R = 11;	// Assign RG6/RP21 to SCK2 (output)
		RPOR9bits.RP19R = 10;	// Assign RG8/RP19 to SDO2 (output)
		RPINR22bits.SDI2R = 26;	// Assign RG7/RP26 to SDI2 (input)
		
		// Configure UART2 PPS pins (MAX3232 on Explorer 16)
		RPINR19bits.U2RXR = 10;	// Assign RF4/RP10 to U2RX (input)
		RPOR8bits.RP17R = 5;	// Assign RF5/RP17 to U2TX (output)
		
		// Configure INT3 PPS pin (MRF24WB0M PICtail Plus interrupt signal)
		RPINR1bits.INT3R = 36;	// Assign RA14/RPI36 to INT3 (input)
	
		__builtin_write_OSCCONL(OSCCON | 0x40); // Lock PPS
	#endif	//#if defined(__PIC24FJ256GA110__)
	
	#if defined(SPIRAM_CS_TRIS)
		SPIRAMInit();
	#endif	//#if defined(SPIRAM_CS_TRIS)
	
	#if defined(EEPROM_CS_TRIS)
		XEEInit();
	#endif	//#if defined(EEPROM_CS_TRIS)
	
	#if defined(SPIFLASH_CS_TRIS)
		SPIFlashInit();
	#endif	//#if defined(SPIFLASH_CS_TRIS)
	
	Adc_Initialization_Service ();
}
//end Initialize_System


/******************************************************************************
 Function:        	void Initialize_Application_Configuration (void)
 Precondition:    	MPFSInit() is already called.
 Input:           	None
 Output:         	Write/Read non-volatile config variables.
 Side Effects:    	None
 Description:       None
 *****************************************************************************/
// MAC Address Serialization using a MPLAB PM3 Programmer and 
// Serialized Quick Turn Programming (SQTP). 
// The advantage of using SQTP for programming the MAC Address is it
// allows you to auto-increment the MAC address without recompiling 
// the code for each unit.  To use SQTP, the MAC address must be fixed
// at a specific location in program memory.  Uncomment these two pragmas
// that locate the MAC address at 0x1FFF0.  Syntax below is for MPLAB C 
// Compiler for PIC18 MCUs. Syntax will vary for other compilers.

//#pragma romdata MACROM=0x1FFF0
//static ROM BYTE SerializedMACAddress[6] = {MY_DEFAULT_MAC_BYTE1, MY_DEFAULT_MAC_BYTE2, MY_DEFAULT_MAC_BYTE3, MY_DEFAULT_MAC_BYTE4, MY_DEFAULT_MAC_BYTE5, MY_DEFAULT_MAC_BYTE6};
//#pragma romdata

void Initialize_Application_Configuration (void)
{
#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
	unsigned char vNeedToSaveDefaults = 0;
#endif	//#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
	
	while(1)
	{
		// Start out zeroing all AppConfig bytes to ensure all fields are 
		// deterministic for checksum generation
		memset((void*)&AppConfig, 0x00, sizeof(AppConfig));
		
		AppConfig.Flags.bIsDHCPEnabled = TRUE;
		AppConfig.Flags.bInConfigMode = TRUE;
		memcpypgm2ram((void*)&AppConfig.MyMACAddr, (ROM void*)SerializedMACAddress, sizeof(AppConfig.MyMACAddr));
//		{
//			_prog_addressT MACAddressAddress;
//			MACAddressAddress.next = 0x157F8;
//			_memcpy_p2d24((char*)&AppConfig.MyMACAddr, MACAddressAddress, sizeof(AppConfig.MyMACAddr));
//		}
		AppConfig.MyIPAddr.Val = MY_DEFAULT_IP_ADDR_BYTE1 | MY_DEFAULT_IP_ADDR_BYTE2<<8ul | MY_DEFAULT_IP_ADDR_BYTE3<<16ul | MY_DEFAULT_IP_ADDR_BYTE4<<24ul;
		AppConfig.DefaultIPAddr.Val = AppConfig.MyIPAddr.Val;
		AppConfig.MyMask.Val = MY_DEFAULT_MASK_BYTE1 | MY_DEFAULT_MASK_BYTE2<<8ul | MY_DEFAULT_MASK_BYTE3<<16ul | MY_DEFAULT_MASK_BYTE4<<24ul;
		AppConfig.DefaultMask.Val = AppConfig.MyMask.Val;
		AppConfig.MyGateway.Val = MY_DEFAULT_GATE_BYTE1 | MY_DEFAULT_GATE_BYTE2<<8ul | MY_DEFAULT_GATE_BYTE3<<16ul | MY_DEFAULT_GATE_BYTE4<<24ul;
		AppConfig.PrimaryDNSServer.Val = MY_DEFAULT_PRIMARY_DNS_BYTE1 | MY_DEFAULT_PRIMARY_DNS_BYTE2<<8ul  | MY_DEFAULT_PRIMARY_DNS_BYTE3<<16ul  | MY_DEFAULT_PRIMARY_DNS_BYTE4<<24ul;
		AppConfig.SecondaryDNSServer.Val = MY_DEFAULT_SECONDARY_DNS_BYTE1 | MY_DEFAULT_SECONDARY_DNS_BYTE2<<8ul  | MY_DEFAULT_SECONDARY_DNS_BYTE3<<16ul  | MY_DEFAULT_SECONDARY_DNS_BYTE4<<24ul;
	
	
		// SNMP Community String configuration
		#if defined(STACK_USE_SNMP_SERVER)
		{
			BYTE i;
			static ROM char * ROM cReadCommunities[] = SNMP_READ_COMMUNITIES;
			static ROM char * ROM cWriteCommunities[] = SNMP_WRITE_COMMUNITIES;
			ROM char * strCommunity;
			
			for(i = 0; i < SNMP_MAX_COMMUNITY_SUPPORT; i++)
			{
				// Get a pointer to the next community string
				strCommunity = cReadCommunities[i];
				if(i >= sizeof(cReadCommunities)/sizeof(cReadCommunities[0]))
					strCommunity = "";
	
				// Ensure we don't buffer overflow.  If your code gets stuck here, 
				// it means your SNMP_COMMUNITY_MAX_LEN definition in TCPIPConfig.h 
				// is either too small or one of your community string lengths 
				// (SNMP_READ_COMMUNITIES) are too large.  Fix either.
				if(strlenpgm(strCommunity) >= sizeof(AppConfig.readCommunity[0]))
					while(1);
				
				// Copy string into AppConfig
				strcpypgm2ram((char*)AppConfig.readCommunity[i], strCommunity);
	
				// Get a pointer to the next community string
				strCommunity = cWriteCommunities[i];
				if(i >= sizeof(cWriteCommunities)/sizeof(cWriteCommunities[0]))
					strCommunity = "";
	
				// Ensure we don't buffer overflow.  If your code gets stuck here, 
				// it means your SNMP_COMMUNITY_MAX_LEN definition in TCPIPConfig.h 
				// is either too small or one of your community string lengths 
				// (SNMP_WRITE_COMMUNITIES) are too large.  Fix either.
				if(strlenpgm(strCommunity) >= sizeof(AppConfig.writeCommunity[0]))
					while(1);
	
				// Copy string into AppConfig
				strcpypgm2ram((char*)AppConfig.writeCommunity[i], strCommunity);
			}
		}
		#endif	//#if defined(STACK_USE_SNMP_SERVER)
	
		// Load the default NetBIOS Host Name
		memcpypgm2ram(AppConfig.NetBIOSName, (ROM void*)MY_DEFAULT_HOST_NAME, 16);
		FormatNetBIOSName(AppConfig.NetBIOSName);
	
		#if defined(WF_CS_TRIS)
			// Load the default SSID Name
			WF_ASSERT(sizeof(MY_DEFAULT_SSID_NAME) <= sizeof(AppConfig.MySSID));
			memcpypgm2ram(AppConfig.MySSID, (ROM void*)MY_DEFAULT_SSID_NAME, sizeof(MY_DEFAULT_SSID_NAME));
			AppConfig.SsidLength = sizeof(MY_DEFAULT_SSID_NAME) - 1;
	
	        AppConfig.SecurityMode = MY_DEFAULT_WIFI_SECURITY_MODE;
	        AppConfig.WepKeyIndex  = MY_DEFAULT_WEP_KEY_INDEX;
	        
	        #if (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_OPEN)
	            memset(AppConfig.SecurityKey, 0x00, sizeof(AppConfig.SecurityKey));
	            AppConfig.SecurityKeyLength = 0;
	
	        #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WEP_40
	            memcpypgm2ram(AppConfig.SecurityKey, (ROM void*)MY_DEFAULT_WEP_KEYS_40, sizeof(MY_DEFAULT_WEP_KEYS_40) - 1);
	            AppConfig.SecurityKeyLength = sizeof(MY_DEFAULT_WEP_KEYS_40) - 1;
	
	        #elif MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WEP_104
			    memcpypgm2ram(AppConfig.SecurityKey, (ROM void*)MY_DEFAULT_WEP_KEYS_104, sizeof(MY_DEFAULT_WEP_KEYS_104) - 1);
			    AppConfig.SecurityKeyLength = sizeof(MY_DEFAULT_WEP_KEYS_104) - 1;
	
	        #elif (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_WITH_KEY)       || \
	              (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA2_WITH_KEY)      || \
	              (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_AUTO_WITH_KEY)
			    memcpypgm2ram(AppConfig.SecurityKey, (ROM void*)MY_DEFAULT_PSK, sizeof(MY_DEFAULT_PSK) - 1);
			    AppConfig.SecurityKeyLength = sizeof(MY_DEFAULT_PSK) - 1;
	
	        #elif (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_WITH_PASS_PHRASE)     || \
	              (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA2_WITH_PASS_PHRASE)    || \
	              (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_WPA_AUTO_WITH_PASS_PHRASE)
	            memcpypgm2ram(AppConfig.SecurityKey, (ROM void*)MY_DEFAULT_PSK_PHRASE, sizeof(MY_DEFAULT_PSK_PHRASE) - 1);
	            AppConfig.SecurityKeyLength = sizeof(MY_DEFAULT_PSK_PHRASE) - 1;
	
	        #else 
	            #error "No security defined"
	        #endif //#if (MY_DEFAULT_WIFI_SECURITY_MODE == WF_SECURITY_OPEN)
		#endif	//#if defined(WF_CS_TRIS)

		// Compute the checksum of the AppConfig defaults as loaded from ROM
		wOriginalAppConfigChecksum = CalcIPChecksum((BYTE*)&AppConfig, sizeof(AppConfig));

		#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
		{
			NVM_VALIDATION_STRUCT NVMValidationStruct;

			// Check to see if we have a flag set indicating that we need to 
			// save the ROM default AppConfig values.
			if(vNeedToSaveDefaults)
				Save_Application_Configuration (&AppConfig);
		
			// Read the NVMValidation record and AppConfig struct out of EEPROM/Flash
			#if defined(EEPROM_CS_TRIS)
			{
				XEEReadArray(0x0000, (BYTE*)&NVMValidationStruct, sizeof(NVMValidationStruct));
				XEEReadArray(sizeof(NVMValidationStruct), (BYTE*)&AppConfig, sizeof(AppConfig));
			}
			#elif defined(SPIFLASH_CS_TRIS)
			{
				SPIFlashReadArray(0x0000, (BYTE*)&NVMValidationStruct, sizeof(NVMValidationStruct));
				SPIFlashReadArray(sizeof(NVMValidationStruct), (BYTE*)&AppConfig, sizeof(AppConfig));
			}
			#endif	//#if defined(EEPROM_CS_TRIS)
	
			// Check EEPROM/Flash validitity.  If it isn't valid, set a flag so 
			// that we will save the ROM default values on the next loop 
			// iteration.
			if((NVMValidationStruct.wConfigurationLength != sizeof(AppConfig)) ||
			   (NVMValidationStruct.wOriginalChecksum != wOriginalAppConfigChecksum) ||
			   (NVMValidationStruct.wCurrentChecksum != CalcIPChecksum((BYTE*)&AppConfig, sizeof(AppConfig))))
			{
				// Check to ensure that the vNeedToSaveDefaults flag is zero, 
				// indicating that this is the first iteration through the do 
				// loop.  If we have already saved the defaults once and the 
				// EEPROM/Flash still doesn't pass the validity check, then it 
				// means we aren't successfully reading or writing to the 
				// EEPROM/Flash.  This means you have a hardware error and/or 
				// SPI configuration error.
				if(vNeedToSaveDefaults)
				{
					while(1);
				}
				
				// Set flag and restart loop to load ROM defaults and save them
				vNeedToSaveDefaults = 1;
				continue;
			}
			
			// If we get down here, it means the EEPROM/Flash has valid contents 
			// and either matches the ROM defaults or previously matched and 
			// was run-time reconfigured by the user.  In this case, we shall 
			// use the contents loaded from EEPROM/Flash.
			break;
		}
		#endif	//#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
		break;
	}
}
//end Initialize_Application_Configuration


#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
	/******************************************************************************
	 Function:        	Save_Application_Configuration (const APP_CONFIG *ptrAppConfig)
	 Precondition:    	None
	 Input:           	const APP_CONFIG *ptrAppConfig
	 Output:         	None
	 Side Effects:    	None
	 Description:       None
	 *****************************************************************************/
	void Save_Application_Configuration (const APP_CONFIG *ptrAppConfig)
	{
		NVM_VALIDATION_STRUCT NVMValidationStruct;
	
		// Ensure adequate space has been reserved in non-volatile storage to 
		// store the entire AppConfig structure.  If you get stuck in this while(1) 
		// trap, it means you have a design time misconfiguration in TCPIPConfig.h.
		// You must increase MPFS_RESERVE_BLOCK to allocate more space.
		#if defined(STACK_USE_MPFS2)
			if(sizeof(NVMValidationStruct) + sizeof(AppConfig) > MPFS_RESERVE_BLOCK)
				while(1);
		#endif
	
		// Get proper values for the validation structure indicating that we can use 
		// these EEPROM/Flash contents on future boot ups
		NVMValidationStruct.wOriginalChecksum = wOriginalAppConfigChecksum;
		NVMValidationStruct.wCurrentChecksum = CalcIPChecksum((BYTE*)ptrAppConfig, sizeof(APP_CONFIG));
		NVMValidationStruct.wConfigurationLength = sizeof(APP_CONFIG);
	
		// Write the validation struct and current AppConfig contents to EEPROM/Flash
		#if defined(EEPROM_CS_TRIS)
		    XEEBeginWrite(0x0000);
		    XEEWriteArray((BYTE*)&NVMValidationStruct, sizeof(NVMValidationStruct));
			XEEWriteArray((BYTE*)ptrAppConfig, sizeof(APP_CONFIG));
	    #else
			SPIFlashBeginWrite(0x0000);
			SPIFlashWriteArray((BYTE*)&NVMValidationStruct, sizeof(NVMValidationStruct));
			SPIFlashWriteArray((BYTE*)ptrAppConfig, sizeof(APP_CONFIG));
	    #endif	//#if defined(EEPROM_CS_TRIS)
	}
	//end Save_Application_Configuration
#endif	//#if defined(EEPROM_CS_TRIS) || defined(SPIFLASH_CS_TRIS)
 
//========== end initialization_service.c ==========
