/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        stack_service.c
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
*/

//Includes
// Include all headers for any enabled TCPIP Stack functions
#include "TCPIP Stack/TCPIP.h"

#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
	#include "TCPIP Stack/ZeroconfLinkLocal.h"
#endif	//#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
#if defined(STACK_USE_ZEROCONF_MDNS_SD)
	#include "TCPIP Stack/ZeroconfMulticastDNS.h"
#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)
#include "include files.h"


//Fuses


//Variables


//Private Prototypes
 

//Declarations


/******************************************************************************
 Function:        	void Stack_Service (void)
 Precondition:    	None
 Input:           	None
 Output:         	None
 Side Effects:    	None
 Description:       Connects to an 802.11 network.  Customize this function as needed 
					for your application.
 *****************************************************************************/
void Stack_Service (void)
{
	//static DWORD t = 0;
	static DWORD dwLastIP = 0;
	#if defined(WF_USE_POWER_SAVE_FUNCTIONS)
	BOOL  PsPollEnabled;
	BOOL  psConfDone = FALSE;
	#endif

	#if defined(WF_USE_POWER_SAVE_FUNCTIONS)
		if (!psConfDone && WFisConnected()) {	
			PsPollEnabled = (MY_DEFAULT_PS_POLL == WF_ENABLED);
			if (!PsPollEnabled) {	 
				/* disable low power (PS-Poll) mode */
				#if defined(STACK_USE_UART)
				putrsUART("Disable PS-Poll\r\n");		 
				#endif
				WF_PsPollDisable();
			} else {
				/* Enable low power (PS-Poll) mode */
				#if defined(STACK_USE_UART)
				putrsUART("Enable PS-Poll\r\n");		
				#endif
				WF_PsPollEnable(TRUE);
			}	
			psConfDone = TRUE;
		}
	#endif	//#if defined(WF_USE_POWER_SAVE_FUNCTIONS)
	
/*	
	//Blink LED0 (right most one) every second.
	if(TickGet() - t >= TICK_SECOND/2ul)
	{
		if (BUTTON2_IO == FALSE)
		{
			DelayMs(1);
			if (BUTTON2_IO == FALSE)
				Measure_Temperature ();
		}
		if (BUTTON3_IO == FALSE)
		{
			DelayMs(1);
			if (BUTTON3_IO == FALSE)
				Measure_Pot_Voltage ();
		}
	    t = TickGet();
	    LED0_IO ^= 1;
	}
*/
	
	//This task performs normal stack task including checking
	//for incoming packet, type of packet and calling
	//appropriate stack entity to process it.
	StackTask();
	
	//This tasks invokes each of the core stack application tasks
	StackApplications();
	
	#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
		ZeroconfLLProcess();
	#endif	//#if defined(STACK_USE_ZEROCONF_LINK_LOCAL)
	
	#if defined(STACK_USE_ZEROCONF_MDNS_SD)
		 mDNSProcess();
		// Use this function to exercise service update function
		// HTTPUpdateRecord();
	#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)

	//Process application specific tasks here.
	//For this demo app, this will include the Generic TCP 
	//client and servers, and the SNMP, Ping, and SNMP Trap
	//demos. Following that, we will process any IO from
	//the inputs on the board itself.
	//Any custom modules or processing you need to do should
	//go here.
	#if defined(STACK_USE_GENERIC_TCP_CLIENT_EXAMPLE)
		//GenericTCPClient ();
		Tcp_Client_Service ();
	#endif	//#if defined(STACK_USE_GENERIC_TCP_CLIENT_EXAMPLE)
	
	#if defined(STACK_USE_GENERIC_TCP_SERVER_EXAMPLE)
		//GenericTCPServer();
		Tcp_Server_Service ();
	#endif	//#if defined(STACK_USE_GENERIC_TCP_SERVER_EXAMPLE)
	
	#if defined(STACK_USE_SMTP_CLIENT)
		SMTPDemo();
	#endif	//#if defined(STACK_USE_SMTP_CLIENT)
	
	#if defined(STACK_USE_ICMP_CLIENT)
		Ping_Service ();
	#endif	//#if defined(STACK_USE_ICMP_CLIENT)
	
	#if defined(STACK_USE_SNMP_SERVER) && !defined(SNMP_TRAP_DISABLED)
		//User should use one of the following SNMP demo
		//This routine demonstrates V1 or V2 trap formats with one variable binding.
		SNMPTrapDemo();
	
		#if defined(SNMP_STACK_USE_V2_TRAP) || defined(SNMP_V1_V2_TRAP_WITH_SNMPV3)
			//This routine provides V2 format notifications with multiple (3) variable bindings
			//User should modify this routine to send v2 trap format notifications with the required varbinds.
			//SNMPV2TrapDemo();
		#endif	//#if defined(SNMP_STACK_USE_V2_TRAP) || defined(SNMP_V1_V2_TRAP_WITH_SNMPV3)
	
		if(gSendTrapFlag)
			SNMPSendTrap();
	#endif	//#if defined(STACK_USE_SNMP_SERVER) && !defined(SNMP_TRAP_DISABLED)
	
	#if defined(STACK_USE_BERKELEY_API)
		BerkeleyTCPClientDemo();
		BerkeleyTCPServerDemo();
		BerkeleyUDPClientDemo();
	#endif	//#if defined(STACK_USE_BERKELEY_API)

	//ProcessIO();

	//If the local IP address has changed (ex: due to DHCP lease change)
	//write the new IP address to the LCD display, UART, and Announce 
	//service
	if(dwLastIP != AppConfig.MyIPAddr.Val)
	{
		dwLastIP = AppConfig.MyIPAddr.Val;
		
		#if defined(STACK_USE_UART)
			putrsUART((ROM char*)"\r\nNew IP Address: ");
		#endif	//#if defined(STACK_USE_UART)

		DisplayIPValue(AppConfig.MyIPAddr);

		#if defined(STACK_USE_UART)
			putrsUART((ROM char*)"\r\n");
		#endif	//#if defined(STACK_USE_UART)


		#if defined(STACK_USE_ANNOUNCE)
			AnnounceIP();
		#endif	//#if defined(STACK_USE_ANNOUNCE)

		#if defined(STACK_USE_ZEROCONF_MDNS_SD)
			mDNSFillHostRecord();
		#endif	//#if defined(STACK_USE_ZEROCONF_MDNS_SD)
	}
}
//end Stack_Service

//========== end stack_service.c ==========
