/******************************************************************************
 *
 *			EnviroNet Firmware Version 1.0
 *
 ******************************************************************************
 * FileName:        constants.h
 * Dependencies:    See INCLUDES section below
 * Processor:       dsPIC33
 * Compiler:        MPLAB C30
 * Company:         GrayStone Industries
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Roger Bishop         2/1/11      Revision A.
 ******************************************************************************/

/*
Notes:
The constants.h file of the primary project and user project must contain the same definitions.
*/

#ifndef _CONSTANTS_H
	#define _CONSTANTS_H
	
	#if defined(__dsPIC33FJ256GP710__)
		#include "p33FJ256GP710.h"
	#elif defined(__dsPIC33FJ256MC710A__)
		#include "p33FJ256MC710A.h"
	#elif defined(__PIC24FJ128GA010__)
		#include "p24FJ128GA010.h"
	#endif
	
	// Used for Wi-Fi assertions
	#define WF_MODULE_NUMBER   WF_MODULE_MAIN_DEMO
	#define BAUD_RATE       (19200)		// bps
	#define MAX_PRODUCTS		7
	
	// Application state machine
	enum
	{
		SM_IDLE = 0u,				// No events are pending
		SM_DEBOUNCE_DOWN,			// Button press detected...verify the event
		SM_ADD_COIN,				// A "coin" was "deposited"
		SM_TRY_VEND,				// Vend was requested
		SM_PREV,					// Go back one product
		SM_NEXT,					// Go forward one product
		SM_DISPLAY_WAIT,			// Waiting for a display message timeout
		SM_SHOW_MENU,				// Restore the menu to the screen
		SM_RELEASE_WAIT,			// Waiting for button to be released
		SM_DEBOUNCE_UP				// Verify release of button
	};
	
	//General definitions
	#define ENABLED 		TRUE
	#define DISABLED 		FALSE
	//#define SET				TRUE
	//#define CLEAR 			FALSE
	#define ON				TRUE
	#define OFF				FALSE
	#define SPACE_BIT		FALSE
	#define MARK_BIT		TRUE
	#define LOW				FALSE
	#define HIGH			TRUE
	#define OUTPUT_PIN		FALSE
	#define INPUT_PIN		TRUE
	#define TRANSMITTER		FALSE
	#define RECEIVER		TRUE
	#define NEGATIVE		FALSE
	#define POSITIVE		TRUE
	#define HIGH_BYTE		TRUE
	#define LOW_BYTE		FALSE
	//#define NULL			 0
	//#define EOF 			-1
	#define EMPTY_BYTE	 	0xFF
	#define EMPTY_WORD	 	0xFFFF
	#define NULL_STRING 	0x00
	#define DEACTIVATED 	0xFF
	#define MEMORY_CLEARED 	0xFF
	#define BYTE_BIT_EXTENT		8
	#define BYTE_NIBBLE_EXTENT	2
	#define BYTE_BYTE_EXTENT	1
	#define WORD_BIT_EXTENT		16
	#define WORD_NIBBLE_EXTENT	4
	#define WORD_BYTE_EXTENT	2
	#define LONG_BIT_EXTENT		32
	#define LONG_NIBBLE_EXTENT	8
	#define LONG_BYTE_EXTENT	1
	#define COMMUNICATION_ERROR -1
	
	//ADC channel enumerations
	enum _ADC_CHANNELS
	{
		ADC_CHANNEL_0,
		ADC_CHANNEL_1,	//Not available for ADC
		ADC_CHANNEL_2,
		ADC_CHANNEL_3,
		ADC_CHANNEL_4,
		ADC_CHANNEL_5,
		ADC_CHANNEL_6,
		ADC_CHANNEL_7,
		ADC_CHANNEL_8,
		ADC_CHANNEL_9
	};
		
	//ADC port assignments used to turn ADC channel on/off.
	#define ADC_0_ON		0b1111111111111110
	#define ADC_1_ON		0b1111111111111101
	#define ADC_2_ON		0b1111111111111011
	#define ADC_3_ON		0b1111111111110111
	#define ADC_4_ON		0b1111111111101111
	#define ADC_5_ON		0b1111111111011111
	#define ADC_6_ON		0b1111111110111111
	#define ADC_7_ON		0b1111111101111111
	#define ADC_8_ON		0b1111111011111111
	#define ADC_9_ON		0b1111110111111111
	
#endif
